import { Log } from './log';
import { Pace } from './Pacing';
import { Auth } from './Auth';
export declare type Method = 'GET' | 'POST' | 'PUT';
export interface Options {
    url: string;
    method: Method;
    protocol: string;
    host: string;
    hostname: string;
    port: string;
    pathname: string;
    path: string;
    headers: any;
    rejectUnauthorized: boolean;
}
export interface Response {
    response: IncomingMessage;
    data: string | ArrayBuffer;
    cached?: boolean;
}
export interface IncomingMessage {
    txt: boolean;
    headers: {
        'content-type': string;
    };
    method: string;
    status: number;
    statusCode: number;
    statusMessage: string;
    url: string;
}
export interface Credentials {
    user: string;
    password: string;
}
export interface Decoder {
    (data: string, options: Options): any;
}
export declare class Authenticators {
    private static auths;
    private static authProviders;
    static addAuthProvider(name: string, provider: (credentials: Credentials) => Auth): void;
    static get(authRequest: string, credentials: Credentials, url: string): Auth;
}
export declare class Request {
    private static contentTypes;
    static addContentType(type: string, isText: boolean): void;
    static decoders: {
        str2json: (data: string) => any;
        html2json: (data: string) => any;
    };
    protected readonly log: Log;
    protected pace: Pace;
    private credentials;
    private authToken;
    constructor(_Log?: typeof Log, prefix?: string);
    setCredentials: (user?: string, password?: string) => void;
    setAuthToken: (token?: string) => string;
    setPace: ({ pace, max, collectionPeriod }?: {
        pace?: any;
        max?: number;
        collectionPeriod?: number;
    }) => void;
    clearPace: () => void;
    decode: Decoder;
    get(url: string | URL, { useCached, headers }?: {
        useCached?: boolean;
        headers?: {};
    }): Promise<Response>;
    put(url: string | URL, postData: any, { headers }?: {
        headers?: {};
    }): Promise<Response>;
    post(url: string | URL, postData: any, { headers }?: {
        headers?: {};
    }): Promise<Response>;
    protected getURL(url: string | URL): URL;
    protected getOptions(url: string | URL, method: Method): Options;
    protected decodedRequest(options: Options, useCached: boolean, headers: any, postData?: any): Promise<Response>;
    protected requestOptions(options: Options, useCached: boolean, postData?: any): Promise<Response>;
    protected request(options: Options, postData?: any): Promise<Response>;
    protected issueRequest(options: Options, postData?: any): Promise<Response>;
    protected isTextualContent(contentType: string, contentLength: number, url: string): boolean;
    protected static isTextualRequest(pathName: string): boolean;
}
